@@ -14,9 +14,13 @@ def get_dataset_link():
         raise NoInternetError("Insufficient internet to download available dataset info. Check your internet connection.") from None
     return pd.read_csv(io.StringIO(dataset_link_text), header=0)
 
-def download(dataset):
-    dataset = dataset.lower()
-    link = get_dataset_link()
-    # if the dataset is not specified or not found in the csv file list, return an error.    
-
-    return link
\ No newline at end of file
+def download(input):
+    input = input.upper()
+    data_link = get_dataset_link()
+    target = data_link.loc[data_link['Series'] == input]
+    url = target.iloc[0,1]
+    try:
+        dataset_text = _download_text(url)
+    except NoInternetError:
+        raise NoInternetError("Insufficient internet to download available dataset info. Check your internet connection.") from None
+    return pd.read_csv(io.StringIO(dataset_text), header=0)
\ No newline at end of file
